@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 15.2 Debian package creator
-# Release 2018-11-16
+# DaVinci Resolve 15.2.2 Debian package creator
+# Release 2018-12-14
 # By Daniel Tufvesson
 #
 
@@ -46,70 +46,20 @@ make_executable() {
     fi
 }
 
-extract_inplace_gz() {
-    check_command gunzip
-    if [ -f "$1" ] ; then
-	echo "[EXTRACT] $1"
-	gunzip -f "$1"
-	if [ -e "$1" ] ; then
-	    rm "$1"
-	fi
-    else
-	echo "[MISSING] $1"
-	ERRORS=$((ERRORS+1))
-    fi
-}
-
-extract_inplace_tgz() {
-    check_command tar
-    if [ -f "$1" ] ; then
-	echo "[EXTRACT] $1"
-	tar zxf "$1" -C "$(dirname $1)"
-	if [ -e "$1" ] ; then
-	    rm "$1"
-	fi
-    else
-	echo "[MISSING] $1"
-	ERRORS=$((ERRORS+1))
-    fi
-}
-
-extract_tgz() {
-    check_command tar
-    if [ -f "$1" ] ; then
-	echo "[EXTRACT] $1 [TO] $2"
-	tar zxf "$1" -C "$2"
-    else
-	echo "[MISSING] $1"
-	ERRORS=$((ERRORS+1))
-    fi
-}
-
-extract_zip() {
-    check_command unzip
-    if [ -f "$1" ] ; then
-	echo "[EXTRACT] $1 [TO] $2"
-	unzip -qq "$1" -d "$2"
-    else
-	echo "[MISSING] $1"
-	ERRORS=$((ERRORS+1))
-    fi
-}
-
 # Setup variables
-RESOLVE_VERSION=15.2
-DEB_STEPPING=2
+RESOLVE_VERSION=15.2.2
+DEB_STEPPING=1
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
-	INSTALLER_ARCHIVE=DaVinci_Resolve_Studio_${RESOLVE_VERSION}_Linux.sh
+	INSTALLER_ARCHIVE=DaVinci_Resolve_Studio_${RESOLVE_VERSION}_Linux.run
 	DEB_NAME=davinci-resolve-studio
 	DEB_CONFLICTS=davinci-resolve
 	UNPACK_DIR=./unpack-DaVinci_Resolve_Studio_${RESOLVE_VERSION}_Linux
 	;;
     lite)
 	RESOLVE_NAME="DaVinci Resolve"
-	INSTALLER_ARCHIVE=DaVinci_Resolve_${RESOLVE_VERSION}_Linux.sh
+	INSTALLER_ARCHIVE=DaVinci_Resolve_${RESOLVE_VERSION}_Linux.run
 	DEB_NAME=davinci-resolve
 	DEB_CONFLICTS=davinci-resolve-studio
 	UNPACK_DIR=./unpack-DaVinci_Resolve_${RESOLVE_VERSION}_Linux
@@ -132,18 +82,16 @@ if [ ! -e "${INSTALLER_ARCHIVE}" ] ; then
     exit 1
 fi
 create_directory ${UNPACK_DIR}
-sh ${INSTALLER_ARCHIVE} --noexec --keep --target ${UNPACK_DIR}
+check_command xorriso
+xorriso -osirrox on -indev ${INSTALLER_ARCHIVE} -extract / ${UNPACK_DIR}
 
 # Create destination directories
 create_directory ${DEB_DIR}
 create_directory ${RESOLVE_BASE_DIR}
 
 # Create directories
-create_directory ${RESOLVE_BASE_DIR}/bin
 create_directory ${RESOLVE_BASE_DIR}/configs
-create_directory ${RESOLVE_BASE_DIR}/docs
 create_directory ${RESOLVE_BASE_DIR}/easyDCP
-create_directory ${RESOLVE_BASE_DIR}/graphics
 create_directory ${RESOLVE_BASE_DIR}/logs
 create_directory ${RESOLVE_BASE_DIR}/scripts
 create_directory ${RESOLVE_BASE_DIR}/.LUT
@@ -155,53 +103,24 @@ create_directory ${RESOLVE_BASE_DIR}/Media
 create_directory ${RESOLVE_BASE_DIR}/"Resolve Disk Database"
 
 # Copy objects
-copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
-copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
-copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/bin ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/Control ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/DaVinci\ Resolve\ Panels\ Setup ${RESOLVE_BASE_DIR}
 copy_object ${UNPACK_DIR}/Developer ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/docs ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/Fusion ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/graphics ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
 copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
-copy_object ${UNPACK_DIR}/panels/DaVinciPanelDaemon ${RESOLVE_BASE_DIR}/bin/
-
-copy_object ${UNPACK_DIR}/DaVinci_Resolve_Manual.pdf ${RESOLVE_BASE_DIR}/docs/
-copy_object ${UNPACK_DIR}/resolve ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/bmdpaneld ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/run_bmdpaneld ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/BMDPanelFirmware ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/DPDecoder ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/qt.conf ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/ShowDpxHeader ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/TestIO ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/deviceQuery ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/bandwidthTest ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/oclDeviceQuery ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/oclBandwidthTest ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/VstScanner ${RESOLVE_BASE_DIR}/bin/
-copy_object ${UNPACK_DIR}/rsf/script.getlogs.v4 ${RESOLVE_BASE_DIR}/scripts/
 copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
-copy_object ${UNPACK_DIR}/rsf/script.start ${RESOLVE_BASE_DIR}/scripts/
-copy_object ${UNPACK_DIR}/rsf/Control ${RESOLVE_BASE_DIR}
-copy_object ${UNPACK_DIR}/rsf/DV_Resolve.png ${RESOLVE_BASE_DIR}/graphics
-copy_object ${UNPACK_DIR}/rsf/default-config-linux.dat ${RESOLVE_BASE_DIR}/configs/config.dat-pkg-default
-copy_object ${UNPACK_DIR}/rsf/log-conf.xml ${RESOLVE_BASE_DIR}/configs/log-conf.xml-pkg-default
-copy_object ${UNPACK_DIR}/rsf/default_cm_config.bin ${RESOLVE_BASE_DIR}/DolbyVision/config.bin-pkg-default
-
-# Extract archives
-extract_tgz ${UNPACK_DIR}/panels/libusb-1.0.tgz ${RESOLVE_BASE_DIR}/bin
-extract_tgz ${UNPACK_DIR}/panels/dvpanel-framework-linux-x86_64.tgz ${RESOLVE_BASE_DIR}/bin
-extract_tgz ${UNPACK_DIR}/panels/dvpanel-utility-linux-x86_64.tgz ${RESOLVE_BASE_DIR}
-extract_zip ${UNPACK_DIR}/rsf/fusion_presets.zip ${RESOLVE_BASE_DIR}
-extract_inplace_gz ${RESOLVE_BASE_DIR}/LUT/trim_lut0.dpx.gz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/aaf_runtime_libs_x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/easydcp-rt-linux-x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/fairlight-lib-linux-x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/fusion-rt-linux-x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/ffmpeg-rt-linux-x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/graphviz-rt-linux-x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/log4cxx_runtime_libs_x64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/sonyrawdev-rt-linux-x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/smdk-rt-linux-x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/sstp-rt-linux-x86_64.tgz
-extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/sxavc-rt-linux-x86_64.tgz
+copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/scripts/script.checkfirmware ${RESOLVE_BASE_DIR}/scripts/
+copy_object ${UNPACK_DIR}/scripts/script.getlogs.v4 ${RESOLVE_BASE_DIR}/scripts/
+copy_object ${UNPACK_DIR}/scripts/script.start ${RESOLVE_BASE_DIR}/scripts/
+copy_object ${UNPACK_DIR}/share/default-config-linux.dat ${RESOLVE_BASE_DIR}/configs/config.dat-pkg-default
+copy_object ${UNPACK_DIR}/share/log-conf.xml ${RESOLVE_BASE_DIR}/configs/log-conf.xml-pkg-default
+copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/DolbyVision/config.bin-pkg-default
 
 # Create udev rules
 create_directory ${DEB_DIR}/lib/udev/rules.d
@@ -243,17 +162,17 @@ test -e /opt/resolve/configs/config.dat || cp /opt/resolve/configs/config.dat-pk
 test -e /opt/resolve/configs/log-conf.xml || cp /opt/resolve/configs/log-conf.xml-pkg-default /opt/resolve/configs/log-conf.xml
 test -e /opt/resolve/DolbyVision/config.bin || cp /opt/resolve/DolbyVision/config.bin-pkg-default /opt/resolve/DolbyVision/config.bin
 chmod -R a+rw /opt/resolve/configs
-chmod -R a+rw /opt/resolve/Media
-chmod -R a+rw /opt/resolve/DolbyVision
-chmod -R a+rw /opt/resolve/Fairlight
 chmod -R a+rw /opt/resolve/easyDCP
+chmod -R a+rw /opt/resolve/logs
 chmod -R a+rw /opt/resolve/Developer
-chmod -R a+rw /opt/resolve/"Resolve Disk Database"
+chmod -R a+rw /opt/resolve/DolbyVision
 chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.LUT
 chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /opt/resolve/.crashreport
-chmod -R a+rw /opt/resolve/logs
+chmod -R a+rw /opt/resolve/"Resolve Disk Database"
+chmod -R a+rw /opt/resolve/Fairlight
+chmod -R a+rw /opt/resolve/Media
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
 check_command fakeroot
